jQuery(document).ready(function ($) {

    var formatRepo = function (repo) {
        if (repo.loading)
            return repo.text;

        var markup = '';
        markup += '<div class="select2-result-repository clearfix>';
        markup += '<div class="select2-result-repository__meta>';
        markup += '<div class="select2-result-repository__title">' + repo.first_name + ' ' + repo.last_name + '</div>';
        markup += '</div>';
        markup += '</div>';

        return markup;
    };

    var formatRepoSelection = function (repo) {
        if (repo.hasOwnProperty('first_name') && repo.hasOwnProperty('last_name'))
            return repo.first_name + ' ' + repo.last_name;
        else
            return repo.text;
    };

    let start_date = $('#start_date_datepicker');
    let end_date = $('#end_date_datepicker');

    if (start_date !== undefined && start_date[0] !== undefined) {
        start_date.datepicker({
            dateFormat: 'yy-mm-dd',
            numberOfMonths: 1,
            showButtonPanel: true
        });
        start_date.on('change', function () {
            end_date.datepicker("option", "minDate", $.datepicker.parseDate('yy-mm-dd', start_date[0].value))
        });
        end_date.datepicker({
            dateFormat: 'yy-mm-dd',
            numberOfMonths: 1,
            showButtonPanel: true,
            minDate: $.datepicker.parseDate('yy-mm-dd', start_date[0].value)
        });
    }


    $("#zleadscrm_google_places_api_key_reset").click(function () {
        if (!confirm("Are you sure? This process cannot be undone.")) {
            return false;
        }
        let nonce = $('#reset_api_key_nonce')[0].value;
        let ajax_url = $(this).attr("data-link");

        $.post({
            url: ajax_url,
            data: {
                'action': 'reset_google_api_key',
                'nonce': nonce
            },
            success: function (redirect) {
                window.location.href = redirect;
            }
        })
    });


    $("form#zleadscrm_leads_search_form").submit(function () {
        $('div.zleadscrm_loading_screen').css('display', 'flex');
        $('div.zleadscrm_loading_screen').css('align-items', 'baseline');
    });

    $("a.lead_modify_bookmark").click(function () {
        let ajax_url = $(this).attr("data-link");
        let data = $(this).attr("data-info");
        let is_bookmarked = $(this).attr("data-is-bookmarked");
        let selected_row = $(this);

        $('div.zleadscrm_loading_screen').css('display', 'flex');
        $('div.zleadscrm_loading_screen').css('align-items', 'center');

        $.post({
            url: ajax_url,
            data: {
                'action': 'lead_modify_bookmark',
                'bookmark': data,
                'is_bookmarked': is_bookmarked
            },
            success: function (result) {
                if (result === 'deleted') {
                    selected_row.removeClass('dashicons-star-filled').addClass('dashicons-star-empty');
                    selected_row.attr('data-is-bookmarked', 'false');
                    $('div.zleadscrm_loading_screen').css('display', 'none');
                } else {
                    selected_row.removeClass('dashicons-star-empty').addClass('dashicons-star-filled');
                    selected_row.attr('data-is-bookmarked', 'true');
                    $('div.zleadscrm_loading_screen').css('display', 'none');
                }
            }
        })
    });

    let next_page_button = $("#zleadscrm_next_page_load");
    if (next_page_button !== undefined) {
        if (next_page_button.attr("data-next") === '' || next_page_button.attr("data-next") === undefined) {
            next_page_button.hide();
        }
    }

    next_page_button.click(function () {
        let ajax_url = $(this).attr("data-link");
        let token = $(this).attr("data-next");
        let search_term = $('#zleadscrm_leads_search_term')[0].value;
        let search_business_type = $('#zleadscrm_business_type')[0].value;
        let search_city = $('#zleadscrm_search_city')[0].value;
        let search_state = $('#zleadscrm_search_state')[0].value;
        let search_miles = $('#zleadscrm_search_miles')[0].value;

        $.post({
            url: ajax_url,
            data: {
                'action': 'load_more_leads',
                'search_term': search_term,
                'business_type': search_business_type,
                'city': search_city,
                'state': search_state,
                'miles': search_miles,
                'current_token': token
            },
            success: function (redirect) {
                window.location.href = redirect;
            }
        })
    });

    $("#zleadscrm_previous_page").click(function () {
        let ajax_url = $(this).attr("data-link");
        let current_page = $(this).attr("data-current-page");
        let search_term = $('#zleadscrm_leads_search_term')[0].value;
        let search_business_type = $('#zleadscrm_business_type')[0].value;
        let search_city = $('#zleadscrm_search_city')[0].value;
        let search_state = $('#zleadscrm_search_state')[0].value;
        let search_miles = $('#zleadscrm_search_miles')[0].value;


        $.post({
            url: ajax_url,
            data: {
                'action': 'load_previous_leads',
                'current_page': current_page,
                'search_term': search_term,
                'business_type': search_business_type,
                'city': search_city,
                'state': search_state,
                'miles': search_miles
            },
            success: function (redirect) {
                window.location.href = redirect;
            }
        })
    });

    $("#zleadscrm_next_page").click(function () {
        let ajax_url = $(this).attr("data-link");
        let current_page = $(this).attr("data-current-page");
        let search_term = $('#zleadscrm_leads_search_term')[0].value;
        let search_business_type = $('#zleadscrm_business_type')[0].value;
        let search_city = $('#zleadscrm_search_city')[0].value;
        let search_state = $('#zleadscrm_search_state')[0].value;
        let search_miles = $('#zleadscrm_search_miles')[0].value;

        $.post({
            url: ajax_url,
            data: {
                'action': 'load_next_leads',
                'search_term': search_term,
                'business_type': search_business_type,
                'city': search_city,
                'state': search_state,
                'miles': search_miles,
                'current_page': current_page
            },
            success: function (redirect) {
                window.location.href = redirect;
            }
        })
    });

    let next_page_button_bottom = $("#zleadscrm_next_page_load_bottom");
    if (next_page_button_bottom !== undefined) {
        if (next_page_button_bottom.attr("data-next") === '' || next_page_button_bottom.attr("data-next") === undefined) {
            next_page_button_bottom.hide();
        }
    }

    next_page_button_bottom.click(function () {
        let ajax_url = $(this).attr("data-link");
        let token = $(this).attr("data-next");
        let search_term = $('#zleadscrm_leads_search_term')[0].value;
        let search_business_type = $('#zleadscrm_business_type')[0].value;
        let search_city = $('#zleadscrm_search_city')[0].value;
        let search_state = $('#zleadscrm_search_state')[0].value;
        let search_miles = $('#zleadscrm_search_miles')[0].value;

        $.post({
            url: ajax_url,
            data: {
                'action': 'load_more_leads',
                'search_term': search_term,
                'business_type': search_business_type,
                'city': search_city,
                'state': search_state,
                'miles': search_miles,
                'current_token': token
            },
            success: function (redirect) {
                window.location.href = redirect;
            }
        })
    });

    $("#zleadscrm_previous_page_bottom").click(function () {
        let ajax_url = $(this).attr("data-link");
        let current_page = $(this).attr("data-current-page");
        let search_term = $('#zleadscrm_leads_search_term')[0].value;
        let search_business_type = $('#zleadscrm_business_type')[0].value;
        let search_city = $('#zleadscrm_search_city')[0].value;
        let search_state = $('#zleadscrm_search_state')[0].value;
        let search_miles = $('#zleadscrm_search_miles')[0].value;


        $.post({
            url: ajax_url,
            data: {
                'action': 'load_previous_leads',
                'current_page': current_page,
                'search_term': search_term,
                'business_type': search_business_type,
                'city': search_city,
                'state': search_state,
                'miles': search_miles
            },
            success: function (redirect) {
                window.location.href = redirect;
            }
        })
    });

    $("#zleadscrm_next_page_bottom").click(function () {
        let ajax_url = $(this).attr("data-link");
        let current_page = $(this).attr("data-current-page");
        let search_term = $('#zleadscrm_leads_search_term')[0].value;
        let search_business_type = $('#zleadscrm_business_type')[0].value;
        let search_city = $('#zleadscrm_search_city')[0].value;
        let search_state = $('#zleadscrm_search_state')[0].value;
        let search_miles = $('#zleadscrm_search_miles')[0].value;

        $.post({
            url: ajax_url,
            data: {
                'action': 'load_next_leads',
                'search_term': search_term,
                'business_type': search_business_type,
                'city': search_city,
                'state': search_state,
                'miles': search_miles,
                'current_page': current_page
            },
            success: function (redirect) {
                window.location.href = redirect;
            }
        })
    });

    $('#zleadscrm_brands_select').select2({
        placeholder: 'Select brands...',
        width: '90%'
    });

    $('#zleadscrm_users_basic_search_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_basic_search_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_basic_search_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_basic_search_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_basic_search_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_basic_search_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_basic_search_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_basic_search_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_basic_search_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_basic_search_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_prospect_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_prospect_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_prospect_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_prospect_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_prospect_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_prospect_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_prospect_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_prospect_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_prospect_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_prospect_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_access_analytics_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_access_analytics_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_access_analytics_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_analytics_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_access_analytics_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_access_analytics_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_analytics_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_access_analytics_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_access_analytics_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_access_analytics_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_access_pipelines_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_access_pipelines_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_access_pipelines_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_pipelines_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_access_pipelines_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_access_pipelines_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_pipelines_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_access_pipelines_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_access_pipelines_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_access_pipelines_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_access_my_bookmarks_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_access_my_bookmarks_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_access_my_bookmarks_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_my_bookmarks_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_access_my_bookmarks_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_access_my_bookmarks_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_my_bookmarks_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_access_my_bookmarks_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_access_my_bookmarks_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_access_my_bookmarks_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_access_all_bookmarks_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_access_all_bookmarks_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_access_all_bookmarks_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_all_bookmarks_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_access_all_bookmarks_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_access_all_bookmarks_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_access_all_bookmarks_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_access_all_bookmarks_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_access_all_bookmarks_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_access_all_bookmarks_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_company_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_company_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_company_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_company_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_company_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_company_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_company_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_company_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_company_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_company_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_advanced_search_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_advanced_search_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_advanced_search_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_advanced_search_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_advanced_search_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_advanced_search_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_advanced_search_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_advanced_search_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_advanced_search_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_advanced_search_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_export_search_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_export_search_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_export_search_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_export_search_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_export_search_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_export_search_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_export_search_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_export_search_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_export_search_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_export_search_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_export_leads_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_export_leads_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_export_leads_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_export_leads_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_export_leads_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_export_leads_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_export_leads_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_export_leads_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_export_leads_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_export_leads_list_container').css('display', 'block');
        }
    });

    $('#zleadscrm_users_export_bookmarks_list').select2({
        placeholder: 'Select users...',
        ajax: {
            url: ajaxurl,
            dataType: 'json',
            data: function (params) {
                let query = {
                    search: params.term,
                    action: 'search_admins'
                };

                return query;
            },
            processResults: function (admins) {
                return {
                    results: admins
                }
            },
        },
        escapeMarkup: function (markup) {
            return markup;
        },
        templateResult: formatRepo,
        templateSelection: formatRepoSelection
    });

    if ($('#zleadscrm_users_allowed_export_bookmarks_setting_all')[0] !== undefined) {
        if ($('#zleadscrm_users_allowed_export_bookmarks_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_export_bookmarks_list_container').css('display', 'none');
        }
    }

    $('#zleadscrm_users_allowed_export_bookmarks_setting_all').change(function () {
        if ($('#zleadscrm_users_allowed_export_bookmarks_setting_all')[0].checked) {
            $('#zleadscrm_allowed_users_export_bookmarks_list_container').css('display', 'none');
        }
    });

    $('#zleadscrm_users_allowed_export_bookmarks_setting_users').change(function () {
        if ($('#zleadscrm_users_allowed_export_bookmarks_setting_users')[0].checked) {
            $('#zleadscrm_allowed_users_export_bookmarks_list_container').css('display', 'block');
        }
    });


    $('#zleadscrm_copy_shipping_from_billing').click(function () {
        $('#zleadscrm_shipping_first_name').val($('#zleadscrm_billing_first_name').val());
        $('#zleadscrm_shipping_last_name').val($('#zleadscrm_billing_last_name').val());
        $('#zleadscrm_shipping_company').val($('#zleadscrm_billing_company').val());
        $('#zleadscrm_shipping_address_1').val($('#zleadscrm_billing_address_1').val());
        $('#zleadscrm_shipping_address_2').val($('#zleadscrm_billing_address_2').val());
        $('#zleadscrm_shipping_city').val($('#zleadscrm_billing_city').val());
        $('#zleadscrm_shipping_postcode').val($('#zleadscrm_billing_postcode').val());
        $('#zleadscrm_shipping_state').val($('#zleadscrm_billing_state').val());
        $('#zleadscrm_shipping_country').val($('#zleadscrm_billing_country').val());
    });


    $('body').on('change', 'select#zleadscrm_account_manager_filter', function () {
        var manager_id = $(this).val();
        var link = $(this).attr("data-link");

        if (manager_id === 0)
            window.location.href = link;
        else
            window.location.href = link + '&manager_filter=' + manager_id;
    });

    $('body').on('change', 'select#zleadscrm_leads_sort_by', function () {
        var sort_by = $(this).val();
        var link = $(this).attr("data-link");

        if (sort_by === 'last_name')
            window.location.href = link;
        else
            window.location.href = link + '&sort_by=' + sort_by;
    });

    $('div.acm_lead_notification .notice-dismiss').click(function () {
        let parent = $(this).parent();

        let ajax_url = parent.attr("data-link");
        let user = parent.attr("data-user");
        let redirect = parent.attr("data-redirect");

        $.post({
            url: ajax_url,
            data: {
                'action': 'remove_lead_notification',
                'lead_id': user
            },
            success: function () {
                window.location.href = redirect;
            }
        })
    });

    $('a.acm_lead_notification_link').click(function () {
        let ajax_url = $(this).attr("data-link");
        let user = $(this).attr("data-user");
        let redirect = $(this).attr("data-redirect");

        $.post({
            url: ajax_url,
            data: {
                'action': 'remove_lead_notification',
                'lead_id': user
            },
            success: function () {
                window.location.href = redirect;
            }
        })
    });


    $('body').on('change', 'div.audit_paging input#current-page-selector', function () {
        var paged = $(this)[0].value;

        window.location.href = window.location.href + '&paged=' + paged;
    });

    $('body').on('change', 'div.lead_paging input#current-page-selector', function () {
        var paged = $(this)[0].value;

        window.location.href = window.location.href + '&paged=' + paged;
    });

    $('a#zleadscrm_lead_change_archive_status').click(function () {
        let ajax_url = $(this).attr("data-link");
        let lead = $(this).attr("data-lead");

        $('div.zleadscrm_loading_screen').css('display', 'flex');
        $('div.zleadscrm_loading_screen').css('align-items', 'center');

        $.post({
            url: ajax_url,
            data: {
                'action': 'change_lead_archive_status',
                'lead_id': lead
            },
            success: function (result) {
                window.location.href = window.location.href + '&upd=1';
            }
        })
    });
});