<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	if ( ! class_exists( 'ZLEADSCRM_PROSPECT_Core_Leads_Result' ) ) {
		require_once( ZLEADSCRM_PROSPECT_PLUGIN_DIR . 'helper/class-zleadscrm-core-leads-result.php' );
	}

	class ZLEADSCRM_PROSPECT_Core_Admin {
		public function __construct() {
			add_action( 'plugins_loaded', array( $this, 'init_hooks' ), 80 );
		}


		public function init_hooks() {
			if ( ! class_exists( 'ZLEADSCRM_BASIC_Core' ) ) {
				add_action( 'admin_notices', function () {
					?>
                    <div class="notice notice-error is-dismissible">
                        <p>To be able to use Leads Prospect Add-on, you need to install the Leads Basic Plugin
                            first!</p>
                    </div>
					<?php

				} );

				return;
			}

			add_action( 'admin_init', array( $this, 'admin_init' ) );

			add_action( 'admin_footer', array( $this, 'powered_by_google_footer' ), 10 );

			add_action( 'admin_menu', array( $this, 'admin_menu' ), 20 ); // Add Menu Item
			add_action( 'delete_user', array( $this, 'delete_user' ), 1 );

			/* Form Post */
			add_action( 'admin_post_zleadscrm_edit_settings', array( $this, 'edit_settings' ), 30 );
			add_action( 'admin_post_zleadscrm_leads_search', array( $this, 'leads_search' ) );
			add_action( 'admin_post_zleadscrm_edit_user_limits', array( $this, 'edit_user_limits' ) );

			/*Ajax Post*/
			add_action( 'wp_ajax_reset_google_api_key', array( $this, 'reset_api_key' ) );
			add_action( 'wp_ajax_nopriv_reset_google_api_key', array( $this, 'reset_api_key' ) );
			add_action( 'wp_ajax_load_more_leads', array( 'ZLEADSCRM_PROSPECT_Core_Leads_Result', 'add_next_page' ) );
			add_action( 'wp_ajax_nopriv_load_more_leads', array(
				'ZLEADSCRM_PROSPECT_Core_Leads_Result',
				'add_next_page'
			) );
			add_action( 'wp_ajax_load_previous_leads', array(
				'ZLEADSCRM_PROSPECT_Core_Leads_Result',
				'load_previous_page'
			) );
			add_action( 'wp_ajax_nopriv_load_previous_leads', array(
				'ZLEADSCRM_PROSPECT_Core_Leads_Result',
				'load_previous_page'
			) );
			add_action( 'wp_ajax_load_next_leads', array( 'ZLEADSCRM_PROSPECT_Core_Leads_Result', 'load_next_page' ) );
			add_action( 'wp_ajax_nopriv_load_next_leads', array(
				'ZLEADSCRM_PROSPECT_Core_Leads_Result',
				'load_next_page'
			) );
			add_action( 'wp_ajax_lead_modify_bookmark', array( $this, 'lead_modify_bookmark' ) );
			add_action( 'wp_ajax_nopriv_lead_modify_bookmark', array( $this, 'lead_modify_bookmark' ) );
		}

		public function admin_init() {
		}

		public function delete_user( $user_id ) {
			global $wpdb;
			$bookmarks_table = $wpdb->prefix . 'zleadscrm_leads_bookmarks';
			$analytics_table = $wpdb->prefix . 'zleadscrm_leads_user_analytics';

			$wpdb->delete( $bookmarks_table, array( 'owner_id' => $user_id ) );
			$wpdb->delete( $analytics_table, array( 'user_id' => $user_id ) );
		}

		public function powered_by_google_footer() {
			$screen = get_current_screen();
			if ( $screen->id == 'leads_page_zleadscrm_leads' ) {
				echo '<div style="position: absolute; bottom: 0; left: 0; right: 0; padding: 0 20px 40px 20px; color: #555d66;">';
				echo '<p id="powered-by-google" class="alignright">';
				echo '<img  alt="powered-by-Google" src="' . plugin_dir_url( ZLEADSCRM_PROSPECT_BASE_FILE ) . 'asset/google-logo.png"/>';
				echo '</p>';
				echo '</div>';
			}
		}

		public function lead_modify_bookmark() {
			global $wpdb;
			$table_name = $wpdb->prefix . 'zleadscrm_leads_bookmarks';

			do_action( 'zleadscrm_last_active_action' );

			$bookmark      = str_replace( "\\", "", sanitize_text_field( $_POST['bookmark'] ) );
			$is_bookmarked = sanitize_text_field( $_POST['is_bookmarked'] );

			if ( zleadscrm_user_can_do_advanced_search( get_current_user_id() ) ) {

				$result        = explode( "~", $bookmark );
				$business_name = $result[0];
				$business_type = $result[1];
				$phone         = $result[2];
				$website       = $result[3];
				$address       = $result[4];
				$owner         = $result[5];
				$url           = $result[6];
			} else {
				$result        = explode( "~", $bookmark );
				$business_name = $result[0];
				$business_type = $result[1];
				$address       = $result[2];
				$owner         = $result[3];
				$url           = $result[4];
				$phone         = '';
				$website       = '';
			}

			if ( $is_bookmarked == 'true' ) {
				$wpdb->delete( $table_name, array(
					'business_name' => $business_name,
					'business_type' => $business_type,
					'address'       => $address,
					'owner_id'      => $owner,
					'url'           => $url
				) );
				print( "deleted" );
				exit();
			} else {
				zleadscrm_insert_bookmark( array(
					'business_name' => $business_name,
					'business_type' => $business_type,
					'phone'         => $phone,
					'website'       => $website,
					'address'       => $address,
					'owner'         => $owner,
					'url'           => $url
				) );

				print( "added" );
				exit();
			}

		}

		public function set_html_content_type() {
			return 'text/html;  charset=utf-8';
		}

		public function edit_settings() {
			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'zleadscrm_edit_settings' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_settings' );
				exit();
			}

			if ( isset( $_POST['zleadscrm_google_places_api_key'] ) ) {
				update_option( 'zleadscrm_google_places_api_key', sanitize_text_field( $_POST['zleadscrm_google_places_api_key'] ) );
			}

			if ( isset( $_POST['zleadscrm_limit_call_number'] ) ) {
				update_option( 'zleadscrm_limit_call_number', (int) sanitize_text_field( $_POST['zleadscrm_limit_call_number'] ) );
			}

			if ( isset( $_POST['zleadscrm_users_allowed_prospect_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_prospect_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_prospect_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_prospect_users'] ) ) {
				update_option( 'zleadscrm_allowed_prospect_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_prospect_users'] ) );
			}

			if ( isset( $_POST['zleadscrm_users_allowed_access_my_bookmarks_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_access_my_bookmarks_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_access_my_bookmarks_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_access_my_bookmarks_users'] ) ) {
				update_option( 'zleadscrm_allowed_access_my_bookmarks_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_access_my_bookmarks_users'] ) );
			}

			if ( isset( $_POST['zleadscrm_users_allowed_access_all_bookmarks_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_access_all_bookmarks_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_access_all_bookmarks_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_access_all_bookmarks_users'] ) ) {
				update_option( 'zleadscrm_allowed_access_all_bookmarks_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_access_all_bookmarks_users'] ) );
			}

			if ( isset( $_POST['zleadscrm_users_allowed_basic_search_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_basic_search_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_basic_search_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_basic_search_users'] ) ) {
				update_option( 'zleadscrm_allowed_basic_search_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_basic_search_users'] ) );
			}

			if ( isset( $_POST['zleadscrm_users_allowed_advanced_search_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_advanced_search_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_advanced_search_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_advanced_search_users'] ) ) {
				update_option( 'zleadscrm_allowed_advanced_search_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_advanced_search_users'] ) );
			}
			if ( ! class_exists( 'ZLEADSCRM_PIPELINE_Core' ) && ! class_exists( 'ZLEADSCRM_ANALYTICS_CORE' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_settings&_wpnonce=' . $_POST['_wpnonce'] );
				exit();
			}
		}

		public function edit_user_limits() {
			$user_id = $_POST['user_id'];

			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'zleadscrm_edit_user_limits' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_insights&user_id=' . $user_id );
				exit();
			}

			if ( isset( $_POST['zleadscrm_month_limit'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_month_max_advanced_requests', (int) sanitize_text_field( $_POST['zleadscrm_month_limit'] ) );
			}

			if ( isset( $_POST['zleadscrm_week_limit'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_week_max_advanced_requests', (int) sanitize_text_field( $_POST['zleadscrm_week_limit'] ) );
			}

			if ( isset( $_POST['zleadscrm_week_limit_type'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_week_limit_type', sanitize_text_field( $_POST['zleadscrm_week_limit_type'] ) );
			}

			if ( isset( $_POST['zleadscrm_month_limit_type'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_month_limit_type', sanitize_text_field( $_POST['zleadscrm_month_limit_type'] ) );
			}

			if ( isset( $_POST['zleadscrm_basic_month_limit'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_month_max_basic_requests', (int) sanitize_text_field( $_POST['zleadscrm_basic_month_limit'] ) );
			}

			if ( isset( $_POST['zleadscrm_basic_week_limit'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_week_max_basic_requests', (int) sanitize_text_field( $_POST['zleadscrm_basic_week_limit'] ) );
			}

			if ( isset( $_POST['zleadscrm_basic_week_limit_type'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_basic_week_limit_type', sanitize_text_field( $_POST['zleadscrm_basic_week_limit_type'] ) );
			}

			if ( isset( $_POST['zleadscrm_basic_month_limit_type'] ) ) {
				update_user_meta( $user_id, 'zleadscrm_basic_month_limit_type', sanitize_text_field( $_POST['zleadscrm_basic_month_limit_type'] ) );
			}

			wp_redirect( 'admin.php?page=zleadscrm_insights&user_id=' . $user_id );
			exit();
		}

		public function reset_api_key() {
			if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( $_POST['nonce'], 'zleadscrm_reset_google_api_key' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_settings' );
				exit();
			}

			delete_option( 'zleadscrm_google_places_api_key' );

			print( admin_url() . 'admin.php?page=zleadscrm_settings' );
			exit();
		}

		public function leads_search() {
			do_action( 'zleadscrm_last_active_action' );

			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'zleadscrm_leads_search' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_leads' );
				exit();
			}

			$link = 'admin.php?page=zleadscrm_leads';

			if ( isset( $_POST['zleadscrm_leads_search_term'] ) ) {
				$link .= '&search_term=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['zleadscrm_leads_search_term'] ) );
			}

			if ( isset( $_POST['zleadscrm_business_type'] ) ) {
				$link .= '&business_type=' . sanitize_text_field( $_POST['zleadscrm_business_type'] );
			}

			if ( isset( $_POST['zleadscrm_search_city'] ) ) {
				$link .= '&city=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['zleadscrm_search_city'] ) );
			}

			if ( isset( $_POST['zleadscrm_search_state'] ) ) {
				$link .= '&state=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['zleadscrm_search_state'] ) );
			}

			if ( isset( $_POST['zleadscrm_search_miles'] ) ) {
				$link .= '&miles=' . (int) sanitize_text_field( $_POST['zleadscrm_search_miles'] );
			}

			wp_redirect( $link );
			exit();
		}

		public function admin_menu() {

			if ( zleadscrm_user_can_prospect( get_current_user_id() ) ) {
				add_menu_page( 'Leads', 'Leads', 'read', 'zleadscrm_bookmarks', array(
					$this,
					'show_zleadscrm_bookmarks'
				), 'dashicons-index-card', 70 );


				add_submenu_page( 'zleadscrm_bookmarks', 'Leads', 'Leads', 'read', 'zleadscrm_bookmarks', array(
					$this,
					'show_zleadscrm_bookmarks'
				) );

				add_submenu_page( 'zleadscrm_bookmarks', 'Prospect', 'Prospect', 'read', 'zleadscrm_leads', array(
					$this,
					'show_zleadscrm_leads'
				) );

				if ( ! class_exists( 'ZLEADSCRM_ANALYTICS_Core' ) && zleadscrm_user_can_access_analytics( get_current_user_id() ) ) {
					add_submenu_page( 'zleadscrm_bookmarks', 'Analytics', 'Analytics', 'read', 'zleadscrm_insights', array(
						$this,
						'show_zleadscrm_insights'
					) );
				}

			} else {
				add_menu_page( 'Leads', 'Leads', 'read', 'zleadscrm_bookmarks', array(
					$this,
					'show_zleadscrm_bookmarks'
				), 'dashicons-index-card', 70 );

				add_submenu_page( 'zleadscrm_bookmarks', 'Leads', 'Leads', 'read', 'zleadscrm_bookmarks', array(
					$this,
					'show_zleadscrm_bookmarks'
				) );

				if ( ! class_exists( 'ZLEADSCRM_ANALYTICS_Core' ) && zleadscrm_user_can_access_analytics( get_current_user_id() ) ) {
					add_submenu_page( 'zleadscrm_bookmarks', 'Analytics', 'Analytics', 'read', 'zleadscrm_insights', array(
						$this,
						'show_zleadscrm_insights'
					) );
				}

			}

			zleadscrm_sort_zleadscrm_menu();
		}

		public function show_zleadscrm_leads() { // Prospect Page
			include_once( ZLEADSCRM_PROSPECT_PLUGIN_DIR . 'template/prospect.php' );

		}

		public function show_zleadscrm_bookmarks() { // Leads Page
			include_once( ZLEADSCRM_PROSPECT_PLUGIN_DIR . 'template/leads.php' );
		}

		public function show_zleadscrm_insights() { // Insights Page
			if ( ! class_exists( 'ZLEADSCRM_ANALYTICS_Core' ) ) {
				include_once( ZLEADSCRM_PROSPECT_PLUGIN_DIR . 'template/insights.php' );
			}
		}

		public function show_zleadscrm_bookmarks_tab( $current ) {
			$tabs = array(
				'leads' => 'Leads'
			);

			if ( zleadscrm_user_can_access_my_bookmarks( get_current_user_id() ) ) {
				$tabs['my_bookmarks'] = 'My Bookmarks';
			}

			if ( zleadscrm_user_can_access_all_bookmarks( get_current_user_id() ) ) {
				$tabs['all_bookmarks'] = 'All Bookmarks';
			}

			$html = '<h2 class="nav-tab-wrapper">';
			foreach ( $tabs as $tab => $name ) {
				$class = ( $tab == $current ) ? 'nav-tab-active' : '';
				$html  .= '<a class="nav-tab ' . esc_attr( $class ) . '" href="?page=zleadscrm_bookmarks&tab=' . $tab . '">' . esc_html( $name ) . '</a>';
			}
			$html .= '</h2>';

			echo $html;
		}

		public function show_zleadscrm_analytics_tab( $current ) {
			$tabs = array(
				'my_analytics' => 'My Analytics'
			);

			if ( zleadscrm_user_can_view_company_analytics( get_current_user_id() ) ) {
				$tabs['company_analytics'] = 'Company Analytics';
			}

			$html = '<h2 class="nav-tab-wrapper">';
			foreach ( $tabs as $tab => $name ) {
				$class = ( $tab == $current ) ? 'nav-tab-active' : '';
				$html  .= '<a class="nav-tab ' . esc_attr( $class ) . '" href="?page=zleadscrm_insights&tab=' . $tab . '">' . esc_html( $name ) . '</a>';
			}
			$html .= '</h2>';

			echo $html;
		}
	}

?>