<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	$current_user_id = get_current_user_id();

	if ( zleadscrm_allow_view_page() == false || zleadscrm_user_can_prospect( $current_user_id ) == false ) {
		echo '<div class="zleadscrm_not_allowed_wrap">';
		echo '<p>Sorry, you are not allowed to access this page!</p>';
		echo '</div>';
		exit;
	}

	$warning = false;
	$o       = '';
	if ( ! zleadscrm_can_do_more_advanced_searches_this_month( $current_user_id, 0 ) ) {
		$warning = true;
		$o       .= '<p>Search Results - Your account has exceeded the number of advanced search results. Ask the administrator to increase the monthly limits for your account.</p>';
	}

	if ( ! zleadscrm_can_do_more_advanced_searches_this_week( $current_user_id, 0 ) ) {
		$warning = true;
		$o       .= '<p>Search Results - Your account has exceeded the number of advanced search results. Ask the administrator to increase the weekly limits for your account.</p>';
	}

	if ( ! zleadscrm_can_do_more_basic_searches_this_month( $current_user_id, 0 ) ) {
		$warning = true;
		$o       .= '<p>Search Results - Your account has exceeded the number of basic search results. Ask the administrator to increase the monthly limits for your account.</p>';
	}

	if ( ! zleadscrm_can_do_more_basic_searches_this_week( $current_user_id, 0 ) ) {
		$warning = true;
		$o       .= '<p>Search Results - Your account has exceeded the number of basic search results. Ask the administrator to increase the weekly limits for your account.</p>';
	}

	if ( $warning ) {
		echo '<div class="notice notice-warning is-dismissible">';
		echo $o;
		echo '</div>';
	}

	$business_types = zleadscrm_get_business_types();

	$query_param = array(
		'search_term'        => '',
		'business_type'      => 'all',
		'city'               => '',
		'state'              => '',
		'miles'              => 10,
		'current_page_token' => '',
		'next_page_token'    => ''
	);

	if ( isset( $_GET['search_term'] ) ) {
		$query_param['search_term'] = str_replace( '%20', ' ', sanitize_text_field( $_GET['search_term'] ) );
	}

	if ( isset( $_GET['business_type'] ) ) {
		$query_param['business_type'] = sanitize_text_field( $_GET['business_type'] );
	}


	if ( isset( $_GET['city'] ) ) {
		$query_param['city'] = str_replace( '%20', ' ', sanitize_text_field( $_GET['city'] ) );
	}

	if ( isset( $_GET['state'] ) ) {
		$query_param['state'] = str_replace( '%20', ' ', sanitize_text_field( $_GET['state'] ) );
	}

	if ( isset( $_GET['miles'] ) ) {
		$query_param['miles'] = (int) sanitize_text_field( $_GET['miles'] );
	}

	if ( isset( $_GET['next_page'] ) ) {
		$query_param['next_page_token'] = sanitize_text_field( $_GET['next_page'] );
	}

	if ( isset( $_GET['current_page'] ) ) {
		$query_param['current_page_token'] = sanitize_text_field( $_GET['current_page'] );
	}

	$search_active = true;
	if ( ! zleadscrm_user_can_do_basic_search( $current_user_id )
	     || ! zleadscrm_can_do_more_basic_searches_this_month( $current_user_id, 0 )
	     || ! zleadscrm_can_do_more_basic_searches_this_week( $current_user_id, 0 ) ) {
		$search_active = false;
	}
?>

<div class="wrap">
    <hr class="wp-header-end"/>
    <h1 style="margin-bottom: 1rem; font-weight: 500;">Prospect</h1>
    <form method="POST" action="<?php echo admin_url( 'admin-post.php' ); ?>" id="zleadscrm_leads_search_form">
        <input type="hidden" name="action" value="zleadscrm_leads_search"/>
		<?php wp_nonce_field( 'zleadscrm_leads_search' ); ?>
		<?php
			if ( $query_param['next_page_token'] != '' ) {
				echo '<input type="hidden" name="zleadscrm_next_page_token" value="' . $query_param['next_page_token'] . '"/>';
			}
		?>
        <div class="zleadscrm_tab_content" style="background: #fff;">
            <div class="zleadscrm_row zleadscrm_disabled_hpadding">
                <div class="zleadscrm_col_12">
                    <div class="zleadscrm_row" style="padding: 15px;">
                        <div class="zleadscrm_col_6 zleadscrm_disabled_padding" style="margin-left:10px;">
                            <div class="zleadscrm_row">
                                <label class="zleadscrm_col_12 zleadscrm_disabled_padding" for="zleadscrm_leads_search_term"
                                       style="font-size: 18px;"><b>Search
                                        for</b></label>
                                <input class="zleadscrm_col_12" type="text" required
                                       value="<?php echo esc_attr( $query_param['search_term'] ); ?>"
                                       name="zleadscrm_leads_search_term"
                                       id="zleadscrm_leads_search_term"
                                       style="height: 45px; font-size:20px; margin-top:10px; margin-right:5px;"/>
                            </div>
                        </div>
                        <div class="zleadscrm_col_3 zleadscrm_disabled_padding zleadscrm_business_type_mobile_layout"
                             style="margin-left:10px;">
                            <div class="zleadscrm_row">
                                <label class="zleadscrm_col_12 zleadscrm_disabled_padding" for="zleadscrm_business_type"
                                       style="font-size:18px;"><b>Select Business
                                        Type</b><br/></label>
                                <select class="zleadscrm_col_12" name="zleadscrm_business_type"
                                        id="zleadscrm_business_type"
                                        style="height: 45px; font-size: 20px; margin-top:10px;">
                                    <option value="all" <?php echo $query_param['business_type'] == 'all' ? 'selected' : ''; ?> >
                                        All
                                    </option>
									<?php
										foreach ( $business_types as $business_type ) {
											$name     = ucfirst( str_replace( '_', ' ', $business_type ) );
											$value    = $business_type;
											$selected = $query_param['business_type'] == $value ? 'selected' : '';
											echo '<option value="' . esc_attr( $value ) . '" ' . $selected . '>' . esc_html( $name ) . '</option>';
										}
									?>
                                </select>
                            </div>
                        </div>

                        <input type="submit" class="button button-primary zleadscrm_col_fill zleadscrm_is_desktop_layout"
                               id="submit_search_button"
                               style="height: 44px; margin-left:10px; align-self: flex-end; margin-bottom: 2px;"
                               value="Search" <?php echo $search_active == false ? 'disabled' : ''; ?>/>
                    </div>
                </div>
                <div class="zleadscrm_col_12 zleadscrm_disabled_padding"
                     style="display: flex; align-items: center; background: #E3E3E3; padding:15px 22px; border: solid 1px #e0e0e0;">
                    <div class="zleadscrm_row zleadscrm_col_12">
                        <div class="zleadscrm_col_4 zleadscrm_disabled_padding">
                            <div class="zleadscrm_row zleadscrm_col_12 zleadscrm_disabled_padding">
                                <span class="zleadscrm_col_3 zleadscrm_disabled_padding zleadscrm_center"
                                      style="font-size:18px; margin-right:10px; text-align: right;"><b>In</b></span>
                                <input class="zleadscrm_col_6" type="text" required placeholder="City"
                                       style="padding: 3px 5px; margin-right:10px; margin-top:10px; margin-bottom: 10px;"
                                       value="<?php echo esc_attr( $query_param['city'] ); ?>"
                                       name="zleadscrm_search_city"
                                       id="zleadscrm_search_city"/>
                                <label class="zleadscrm_col_fill zleadscrm_disabled_padding zleadscrm_center"
                                       for="zleadscrm_search_city"
                                       style="font-size:16px; vertical-align: baseline;">City,</label>
                            </div>
                        </div>
                        <div class="zleadscrm_col_4 zleadscrm_disabled_padding">
                            <div class="zleadscrm_row zleadscrm_col_12 zleadscrm_disabled_padding">
                                <select class="zleadscrm_col_8 zleadscrm_disabled_padding"
                                        style="margin-right: 10px; margin-top:10px; margin-bottom: 10px"
                                        name="zleadscrm_search_state"
                                        id="zleadscrm_search_state" required>
                                    <option value="">Select a state</option>
                                    <option value="Alabama" <?php echo $query_param['state'] == 'Alabama' ? 'selected' : ''; ?>>
                                        United States (US) — Alabama
                                    </option>
                                    <option value="Alaska" <?php echo $query_param['state'] == 'Alabama' ? 'selected' : ''; ?>>
                                        United States (US) — Alaska
                                    </option>
                                    <option value="Arizona" <?php echo $query_param['state'] == 'Arizona' ? 'selected' : ''; ?>>
                                        United States (US) — Arizona
                                    </option>
                                    <option value="Arkansas" <?php echo $query_param['state'] == 'Arkansas' ? 'selected' : ''; ?>>
                                        United States (US) — Arkansas
                                    </option>
                                    <option value="California" <?php echo $query_param['state'] == 'California' ? 'selected' : ''; ?>>
                                        United States (US) — California
                                    </option>
                                    <option value="Colorado" <?php echo $query_param['state'] == 'Colorado' ? 'selected' : ''; ?>>
                                        United States (US) — Colorado
                                    </option>
                                    <option value="Connecticut" <?php echo $query_param['state'] == 'Connecticut' ? 'selected' : ''; ?>>
                                        United States (US) — Connecticut
                                    </option>
                                    <option value="Delaware" <?php echo $query_param['state'] == 'Delaware' ? 'selected' : ''; ?>>
                                        United States (US) — Delaware
                                    </option>
                                    <option value="District of Columbia" <?php echo $query_param['state'] == 'District of Columbia' ? 'selected' : ''; ?>>
                                        United States (US) — District Of Columbia
                                    </option>
                                    <option value="Florida" <?php echo $query_param['state'] == 'Florida' ? 'selected' : ''; ?>>
                                        United States (US) — Florida
                                    </option>
                                    <option value="Georgia" <?php echo $query_param['state'] == 'Georgia' ? 'selected' : ''; ?>>
                                        United States (US) — Georgia
                                    </option>
                                    <option value="Hawaii" <?php echo $query_param['state'] == 'Hawaii' ? 'selected' : ''; ?>>
                                        United States (US) — Hawaii
                                    </option>
                                    <option value="Idaho" <?php echo $query_param['state'] == 'Idaho' ? 'selected' : ''; ?>>
                                        United States (US) — Idaho
                                    </option>
                                    <option value="Illinois" <?php echo $query_param['state'] == 'Illinois' ? 'selected' : ''; ?>>
                                        United States (US) — Illinois
                                    </option>
                                    <option value="Indiana" <?php echo $query_param['state'] == 'Indiana' ? 'selected' : ''; ?>>
                                        United States (US) — Indiana
                                    </option>
                                    <option value="Iowa" <?php echo $query_param['state'] == 'Iowa' ? 'selected' : ''; ?>>
                                        United
                                        States (US) — Iowa
                                    </option>
                                    <option value="Kansas" <?php echo $query_param['state'] == 'Kansas' ? 'selected' : ''; ?>>
                                        United States (US) — Kansas
                                    </option>
                                    <option value="Kentucky" <?php echo $query_param['state'] == 'Kentucky' ? 'selected' : ''; ?>>
                                        United States (US) — Kentucky
                                    </option>
                                    <option value="Louisiana" <?php echo $query_param['state'] == 'Louisiana' ? 'selected' : ''; ?>>
                                        United States (US) — Louisiana
                                    </option>
                                    <option value="Maine" <?php echo $query_param['state'] == 'Maine' ? 'selected' : ''; ?>>
                                        United States (US) — Maine
                                    </option>
                                    <option value="Maryland" <?php echo $query_param['state'] == 'Maryland' ? 'selected' : ''; ?>>
                                        United States (US) — Maryland
                                    </option>
                                    <option value="Massachusetts" <?php echo $query_param['state'] == 'Massachusetts' ? 'selected' : ''; ?>>
                                        United States (US) — Massachusetts
                                    </option>
                                    <option value="Michigan" <?php echo $query_param['state'] == 'Michigan' ? 'selected' : ''; ?>>
                                        United States (US) — Michigan
                                    </option>
                                    <option value="Minnesota" <?php echo $query_param['state'] == 'Minnesota' ? 'selected' : ''; ?>>
                                        United States (US) — Minnesota
                                    </option>
                                    <option value="Mississippi" <?php echo $query_param['state'] == 'Mississippi' ? 'selected' : ''; ?>>
                                        United States (US) — Mississippi
                                    </option>
                                    <option value="Missouri" <?php echo $query_param['state'] == 'Missouri' ? 'selected' : ''; ?>>
                                        United States (US) — Missouri
                                    </option>
                                    <option value="Montana" <?php echo $query_param['state'] == 'Montana' ? 'selected' : ''; ?>>
                                        United States (US) — Montana
                                    </option>
                                    <option value="Nebraska" <?php echo $query_param['state'] == 'Nebraska' ? 'selected' : ''; ?>>
                                        United States (US) — Nebraska
                                    </option>
                                    <option value="Nevada" <?php echo $query_param['state'] == 'Nevada' ? 'selected' : ''; ?>>
                                        United States (US) — Nevada
                                    </option>
                                    <option value="New Hampshire" <?php echo $query_param['state'] == 'New Hampshire' ? 'selected' : ''; ?>>
                                        United States (US) — New Hampshire
                                    </option>
                                    <option value="New Jersey" <?php echo $query_param['state'] == 'New Jersey' ? 'selected' : ''; ?>>
                                        United States (US) — New Jersey
                                    </option>
                                    <option value="New Mexico" <?php echo $query_param['state'] == 'New Mexico' ? 'selected' : ''; ?>>
                                        United States (US) — New Mexico
                                    </option>
                                    <option value="New York" <?php echo $query_param['state'] == 'New York' ? 'selected' : ''; ?>>
                                        United States (US) — New York
                                    </option>
                                    <option value="North Carolina" <?php echo $query_param['state'] == 'North Carolina' ? 'selected' : ''; ?>>
                                        United States (US) — North Carolina
                                    </option>
                                    <option value="North Dakota" <?php echo $query_param['state'] == 'North Dakota' ? 'selected' : ''; ?>>
                                        United States (US) — North Dakota
                                    </option>
                                    <option value="Ohio" <?php echo $query_param['state'] == 'Ohio' ? 'selected' : ''; ?>>
                                        United
                                        States (US) — Ohio
                                    </option>
                                    <option value="Oklahoma" <?php echo $query_param['state'] == 'Oklahoma' ? 'selected' : ''; ?>>
                                        United States (US) — Oklahoma
                                    </option>
                                    <option value="Oregon" <?php echo $query_param['state'] == 'Oregon' ? 'selected' : ''; ?>>
                                        United States (US) — Oregon
                                    </option>
                                    <option value="Pennsylvania" <?php echo $query_param['state'] == 'Pennsylvania' ? 'selected' : ''; ?>>
                                        United States (US) — Pennsylvania
                                    </option>
                                    <option value="Rhode Island" <?php echo $query_param['state'] == 'Rhode Island' ? 'selected' : ''; ?>>
                                        United States (US) — Rhode Island
                                    </option>
                                    <option value="South Carolina" <?php echo $query_param['state'] == 'South Carolina' ? 'selected' : ''; ?>>
                                        United States (US) — South Carolina
                                    </option>
                                    <option value="South Dakota" <?php echo $query_param['state'] == 'South Dakota' ? 'selected' : ''; ?>>
                                        United States (US) — South Dakota
                                    </option>
                                    <option value="Tennessee" <?php echo $query_param['state'] == 'Tennessee' ? 'selected' : ''; ?>>
                                        United States (US) — Tennessee
                                    </option>
                                    <option value="Texas" <?php echo $query_param['state'] == 'Texas' ? 'selected' : ''; ?>>
                                        United States (US) — Texas
                                    </option>
                                    <option value="Utah" <?php echo $query_param['state'] == 'Utah' ? 'selected' : ''; ?>>
                                        United
                                        States (US) — Utah
                                    </option>
                                    <option value="Vermont" <?php echo $query_param['state'] == 'Vermont' ? 'selected' : ''; ?>>
                                        United States (US) — Vermont
                                    </option>
                                    <option value="Virginia" <?php echo $query_param['state'] == 'Virginia' ? 'selected' : ''; ?>>
                                        United States (US) — Virginia
                                    </option>
                                    <option value="Washington" <?php echo $query_param['state'] == 'Washington' ? 'selected' : ''; ?>>
                                        United States (US) — Washington
                                    </option>
                                    <option value="West Virginia" <?php echo $query_param['state'] == 'West Virginia' ? 'selected' : ''; ?>>
                                        United States (US) — West Virginia
                                    </option>
                                    <option value="Wisconsin" <?php echo $query_param['state'] == 'Wisconsin' ? 'selected' : ''; ?>>
                                        United States (US) — Wisconsin
                                    </option>
                                    <option value="Wyoming" <?php echo $query_param['state'] == 'Wyoming' ? 'selected' : ''; ?>>
                                        United States (US) — Wyoming
                                    </option>
                                </select>
                                <label class="zleadscrm_col_fill zleadscrm_disabled_padding zleadscrm_center"
                                       for="zleadscrm_search_state"
                                       style="font-size:16px;">State</label>
                            </div>
                        </div>
                        <div class="zleadscrm_col_fill zleadscrm_disabled_padding">
                            <div class="zleadscrm_row zleadscrm_col_12 zleadscrm_disabled_padding">
                                <label class="zleadscrm_col_3 zleadscrm_disabled_padding zleadscrm_results_apply_col"
                                       style="font-size: 18px; text-align:  right; margin-right: 10px;"><b>Apply</b></label>
                                <input class="zleadscrm_col_3 zleadscrm_disabled_padding zleadscrm_results_apply_col"
                                       type="number" required
                                       value="<?php echo esc_attr( $query_param['miles'] ); ?>" min="0"
                                       max="30"
                                       step="1"
                                       name="zleadscrm_search_miles"
                                       id="zleadscrm_search_miles"
                                       style="padding: 3px 5px; margin-top:10px; margin-bottom: 10px;"/>
                                <div class="zleadscrm_col_fill zleadscrm_center zleadscrm_results_apply_col">
                                    <label for="zleadscrm_search_miles" style="font-size:14px;"><b>Miles
                                            radius</b><br/>(30 miles max radius)</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="zleadscrm_col_12 zleadscrm_is_mobile_layout" style="background: #E3E3E3; text-align: center;">
                    <input type="submit" class="button button-primary zleadscrm_col_9"
                           id="submit_search_button"
                           style="height: 44px; margin-bottom: 2px;"
                           value="Search" <?php echo $search_active == false ? 'disabled' : ''; ?>/>
                </div>
            </div>
        </div>
    </form>
</div>

<?php
	if ( ! class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
		if ( ! class_exists( 'ZLEADSCRM_PROSPECT_Core_Leads_Result' ) ) {
			require_once( ZLEADSCRM_PROSPECT_PLUGIN_DIR . 'helper/class-zleadscrm-core-leads-result.php' );
		}

		$zleadscrm_results = new ZLEADSCRM_PROSPECT_Core_Leads_Result( $query_param );
	} else {
		if ( ! class_exists( 'ZLEADSCRM_EXPORT_Core_Leads_Result' ) ) {
			require_once( ZLEADSCRM_EXPORT_PLUGIN_DIR . 'helper/class-zleadscrm-core-leads-result.php' );
		}

		$zleadscrm_results = new ZLEADSCRM_EXPORT_Core_Leads_Result( $query_param );
	}
?>
<div style="margin-top:2rem; margin-right:1rem; margin-bottom:5rem;">
	<?php $zleadscrm_results->print_overview();
	?>
</div>
<div class="zleadscrm_loading_screen">
    <img alt="loading" style="margin-top: 15rem;"
         src="<?php echo plugin_dir_url( ZLEADSCRM_PROSPECT_BASE_FILE ) . 'asset/wpspin_light-2x.gif' ?>"/>
</div>
<?php
?>
